@@ -31,12 +31,15 @@ __PACKAGE__->belongs_to( "author",  "MojoMojo::Schema::Result::Person",  { id
 
 MojoMojo::Schema::Result::Entry
 
+=head1 AUTHOR
+
+Marcus Ramberg <mramberg@cpan.org>
+
 =head1 LICENSE
 
-This library is free software . You can redistribute it and/or modify 
-it under the same terms as perl itself.
+This library is free software. You can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
 1;
-
